﻿using System;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.Extensions.DependencyInjection;

namespace VaccineRegistration.Persistence
{
    public static class DbInitializer
    {
        public static void Initialize(IServiceProvider serviceProvider)
        {
            var context = serviceProvider.GetRequiredService<VaccineRegistrationContext>();

            context.Database.EnsureCreated();

            if (context.Hospitals.Any())
                return;

            var hospitals = new Hospital[]
            {
                // DailyCapacity értéke szándékosan alacsony a könnyebb tesztelhetőség érdekében
                // módosíthatóak is az értékek tetszés szerint
                new Hospital {Name = "Dél-Pesti Centrumkórház", DailyCapacity = 4},
                new Hospital {Name = "Debreceni Egyetem Klinikai Központ", DailyCapacity = 5},
                new Hospital {Name = "Magyar Honvédség Egészségügyi Központ", DailyCapacity = 3},
                new Hospital {Name = "Markusovszky Egyetemi Oktatókórház", DailyCapacity = 6},
                new Hospital {Name = "Petz Aladár Megyei Oktató Kórház", DailyCapacity = 5},
                new Hospital {Name = "Szent Borbála Kórház", DailyCapacity = 7},
                new Hospital {Name = "Szent Imre Egyetemi Oktatókórház", DailyCapacity = 3},
            };
            context.Hospitals.AddRange(hospitals);

            var vaccines = new Vaccine[]
            {
                new Vaccine { Name = "Pfizer"},
                new Vaccine { Name = "Moderna"},
                new Vaccine { Name = "AstraZeneca"},
                new Vaccine { Name = "Szputnyik V"},
                new Vaccine { Name = "Sinopharm"},
            };
            context.Vaccines.AddRange(vaccines);

            var availabilities = new VaccineAvailability[]
            {
                new VaccineAvailability {Hospital = hospitals[0], Vaccine = vaccines[4]},
                new VaccineAvailability {Hospital = hospitals[1], Vaccine = vaccines[4]},
                new VaccineAvailability {Hospital = hospitals[2], Vaccine = vaccines[4]},
                new VaccineAvailability {Hospital = hospitals[3], Vaccine = vaccines[4]},
                new VaccineAvailability {Hospital = hospitals[4], Vaccine = vaccines[4]},
                new VaccineAvailability {Hospital = hospitals[5], Vaccine = vaccines[4]},
                new VaccineAvailability {Hospital = hospitals[6], Vaccine = vaccines[4]},
                new VaccineAvailability {Hospital = hospitals[0], Vaccine = vaccines[0]},
                new VaccineAvailability {Hospital = hospitals[2], Vaccine = vaccines[0]},
                new VaccineAvailability {Hospital = hospitals[4], Vaccine = vaccines[2]},
                new VaccineAvailability {Hospital = hospitals[5], Vaccine = vaccines[2]},
                new VaccineAvailability {Hospital = hospitals[6], Vaccine = vaccines[2]},
                new VaccineAvailability {Hospital = hospitals[0], Vaccine = vaccines[3]},
                new VaccineAvailability {Hospital = hospitals[1], Vaccine = vaccines[3]},
                new VaccineAvailability {Hospital = hospitals[3], Vaccine = vaccines[3]},
                new VaccineAvailability {Hospital = hospitals[5], Vaccine = vaccines[3]},
            };
            context.VaccineAvailabilities.AddRange(availabilities);

            context.SaveChanges();
        }
    }
}
